summaryrefslogtreecommitdiffstats
path: root/src/H5MF.c
diff options
context:
space:
mode:
authorRaymond Lu <songyulu@hdfgroup.org>2007-01-12 20:29:43 (GMT)
committerRaymond Lu <songyulu@hdfgroup.org>2007-01-12 20:29:43 (GMT)
commit77ce08c35687fc2ed4bf338318aa5fcff46750b0 (patch)
treee4c070170d6be036cb2184c067e39b87e9a60ecc /src/H5MF.c
parent7072d7103d9ec03c4f1d1217cc45e966d867edbc (diff)
downloadhdf5-77ce08c35687fc2ed4bf338318aa5fcff46750b0.zip
hdf5-77ce08c35687fc2ed4bf338318aa5fcff46750b0.tar.gz
hdf5-77ce08c35687fc2ed4bf338318aa5fcff46750b0.tar.bz2
[svn-r13139] Fixed the MULTI problem (Bug #731) that corrupted the data. The problem
came from the EOA for the whole MULTI file. It's taken out because it's meaningless for MULTI file. Instead, each individual file has its EOA.
Diffstat (limited to 'src/H5MF.c')
-rw-r--r--src/H5MF.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/H5MF.c b/src/H5MF.c
index 9fe00b4..eeced47 100644
--- a/src/H5MF.c
+++ b/src/H5MF.c
@@ -38,6 +38,7 @@
#include "H5Fpkg.h"
#include "H5FDprivate.h"
#include "H5MFprivate.h"
+#include "H5FDmulti.h" /*multiple files partitioned by mem usage */
/*-------------------------------------------------------------------------
@@ -234,14 +235,16 @@ done:
hbool_t
H5MF_alloc_overflow(H5F_t *f, hsize_t size)
{
- hsize_t space_needed; /* Accumulator variable */
- size_t c; /* Local index variable */
+ hsize_t space_needed = 0; /* Accumulator variable */
+ H5FD_mem_t type; /* Type of memory */
+ size_t c; /* Local index variable */
hbool_t ret_value; /* Return value */
FUNC_ENTER_NOAPI_NOFUNC(H5MF_alloc_overflow)
/* Start with the current end of the file's address. */
space_needed = (hsize_t)H5F_get_eoa(f);
+
HDassert(H5F_addr_defined(space_needed));
/* Subtract the file's base address to get the actual amount of